# See LICENSE.incore for details

"""Top-level package for RISCOF - RISC-V Architectural Test Framework."""

__author__ = """InCore Semiconductors Pvt Ltd"""
__email__ = 'info@incoresemi.com'
__version__ = '1.20.3'
